@@ -1,7 +1,7 @@
 package Perinci::Sub::GetArgs::Argv;
 
-our $DATE = '2016-10-07'; # DATE
-our $VERSION = '0.74'; # VERSION
+our $DATE = '2016-10-27'; # DATE
+our $VERSION = '0.75'; # VERSION
 
 use 5.010001;
 use strict;
@@ -265,6 +265,8 @@ sub _args2opts {
     for my $arg (keys %$args_prop) {
         my $fqarg    = "$argprefix$arg";
         my $arg_spec = $args_prop->{$arg};
+        next if grep { $_ eq 'hidden' || $_ eq 'hidden-cli' }
+            @{ $arg_spec->{tags} // [] };
         my $sch      = $arg_spec->{schema} // ['any', {}];
         my ($is_simple, $is_array_of_simple, $type, $cset, $eltype) =
             _is_simple_is_array_of_simple($sch);
@@ -1100,7 +1102,7 @@ Perinci::Sub::GetArgs::Argv - Get subroutine arguments from command line argumen
 
 =head1 VERSION
 
-This document describes version 0.74 of Perinci::Sub::GetArgs::Argv (from Perl distribution Perinci-Sub-GetArgs-Argv), released on 2016-10-07.
+This document describes version 0.75 of Perinci::Sub::GetArgs::Argv (from Perl distribution Perinci-Sub-GetArgs-Argv), released on 2016-10-27.
 
 =head1 SYNOPSIS
 
